.. ALLib documentation master file, created by
   sphinx-quickstart on Wed Jan 20 17:13:46 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ALLib's documentation!
=================================
Welcome to the documentation of ALLib! It includes an :doc:`installation
</introduction/installation>` guide, a **quick tour**, details how
to prepare your

ALLib is `open source <https://git.science.uu.nl/mpbron-phd/allib>`_ research
software developed by :ref:`researchers <introduction/about:authors>` at Utrecht
University and the Dutch National Police and is published under the `GNU LGPL 3.0 licence
<https://git.science.uu.nl/mpbron-phd/allib/blob/master/LICENSE>`_.

.. toctree::
   :caption: Introduction
   :maxdepth: 1

   introduction/about
   introduction/installation
   introduction/components
   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
